@@ -22,20 +22,24 @@
  * IN THE SOFTWARE.
  */
 
+#include <stdint.h>
+
 #include <glib-object.h>
+#include <glib.h>
 
-#include <unordered_map>
+#include "gjs/jsapi-wrapper.h"
 
+#include "gi/gobject.h"
+#include "gi/gtype.h"
+#include "gi/interface.h"
+#include "gi/object.h"
+#include "gi/param.h"
+#include "gi/private.h"
+#include "gi/repo.h"
+#include "gjs/atoms.h"
 #include "gjs/context-private.h"
 #include "gjs/jsapi-util-args.h"
 #include "gjs/jsapi-util.h"
-#include "gjs/jsapi-wrapper.h"
-#include "gobject.h"
-#include "interface.h"
-#include "object.h"
-#include "param.h"
-#include "private.h"
-#include "repo.h"
 
 /* gi/private.cpp - private "imports._gi" module with operations that we need
  * to use from JS in order to create GObject classes, but should not be exposed
@@ -229,9 +233,9 @@ static bool gjs_register_interface(JSContext* cx, unsigned argc,
     if (!module)
         return false;  // error will have been thrown already
 
-    JS::RootedObject constructor(cx);
-    if (!gjs_define_interface_class(cx, module, nullptr, interface_type,
-                                    &constructor))
+    JS::RootedObject constructor(cx), ignored_prototype(cx);
+    if (!InterfacePrototype::create_class(cx, module, nullptr, interface_type,
+                                          &constructor, &ignored_prototype))
         return false;
 
     args.rval().setObject(*constructor);
@@ -355,7 +359,7 @@ static bool gjs_signal_new(JSContext* cx, unsigned argc, JS::Value* vp) {
             break;
         case 0:
         default:
-            accumulator = NULL;
+            accumulator = nullptr;
     }
 
     GType return_type;
