@@ -3,61 +3,61 @@ const GLib = imports.gi.GLib;
 
 describe('GVariant constructor', function () {
     it('constructs a string variant', function () {
-        let str_variant = new GLib.Variant('s', 'mystring');
-        expect(str_variant.get_string()[0]).toEqual('mystring');
-        expect(str_variant.deep_unpack()).toEqual('mystring');
+        let strVariant = new GLib.Variant('s', 'mystring');
+        expect(strVariant.get_string()[0]).toEqual('mystring');
+        expect(strVariant.deepUnpack()).toEqual('mystring');
     });
 
     it('constructs a string variant (backwards compatible API)', function () {
-        let str_variant = new GLib.Variant('s', 'mystring');
-        let str_variant_old = GLib.Variant.new('s', 'mystring');
-        expect(str_variant.equal(str_variant_old)).toBeTruthy();
+        let strVariant = new GLib.Variant('s', 'mystring');
+        let strVariantOld = GLib.Variant.new('s', 'mystring');
+        expect(strVariant.equal(strVariantOld)).toBeTruthy();
     });
 
     it('constructs a struct variant', function () {
-        let struct_variant = new GLib.Variant('(sogvau)', [
+        let structVariant = new GLib.Variant('(sogvau)', [
             'a string',
             '/a/object/path',
-            'asig', //nature
+            'asig', // nature
             new GLib.Variant('s', 'variant'),
-            [ 7, 3 ]
+            [7, 3],
         ]);
-        expect(struct_variant.n_children()).toEqual(5);
+        expect(structVariant.n_children()).toEqual(5);
 
-        let unpacked = struct_variant.deep_unpack();
+        let unpacked = structVariant.deepUnpack();
         expect(unpacked[0]).toEqual('a string');
         expect(unpacked[1]).toEqual('/a/object/path');
         expect(unpacked[2]).toEqual('asig');
         expect(unpacked[3] instanceof GLib.Variant).toBeTruthy();
-        expect(unpacked[3].deep_unpack()).toEqual('variant');
+        expect(unpacked[3].deepUnpack()).toEqual('variant');
         expect(unpacked[4] instanceof Array).toBeTruthy();
         expect(unpacked[4].length).toEqual(2);
     });
 
     it('constructs a maybe variant', function () {
-        let maybe_variant = new GLib.Variant('ms', null);
-        expect(maybe_variant.deep_unpack()).toBeNull();
+        let maybeVariant = new GLib.Variant('ms', null);
+        expect(maybeVariant.deepUnpack()).toBeNull();
 
-        maybe_variant = new GLib.Variant('ms', 'string');
-        expect(maybe_variant.deep_unpack()).toEqual('string');
+        maybeVariant = new GLib.Variant('ms', 'string');
+        expect(maybeVariant.deepUnpack()).toEqual('string');
     });
 
     it('constructs a byte array variant', function () {
         const byteArray = Uint8Array.from('pizza', c => c.charCodeAt(0));
         const byteArrayVariant = new GLib.Variant('ay', byteArray);
-        expect(ByteArray.toString(byteArrayVariant.deep_unpack()))
+        expect(ByteArray.toString(byteArrayVariant.deepUnpack()))
             .toEqual('pizza');
     });
 
     it('constructs a byte array variant from a string', function () {
         const byteArrayVariant = new GLib.Variant('ay', 'pizza');
-        expect(ByteArray.toString(byteArrayVariant.deep_unpack()))
+        expect(ByteArray.toString(byteArrayVariant.deepUnpack()))
             .toEqual('pizza');
     });
 
     it('0-terminates a byte array variant constructed from a string', function () {
         const byteArrayVariant = new GLib.Variant('ay', 'pizza');
-        const a = byteArrayVariant.deep_unpack();
+        const a = byteArrayVariant.deepUnpack();
         [112, 105, 122, 122, 97, 0].forEach((val, ix) =>
             expect(a[ix]).toEqual(val));
     });
@@ -65,7 +65,7 @@ describe('GVariant constructor', function () {
     it('does not 0-terminate a byte array variant constructed from a Uint8Array', function () {
         const byteArray = Uint8Array.from('pizza', c => c.charCodeAt(0));
         const byteArrayVariant = new GLib.Variant('ay', byteArray);
-        const a = byteArrayVariant.deep_unpack();
+        const a = byteArrayVariant.deepUnpack();
         [112, 105, 122, 122, 97].forEach((val, ix) =>
             expect(a[ix]).toEqual(val));
     });
