@@ -39,8 +39,9 @@ var _gtkCssName = Symbol('GTK widget CSS name');
 var _gtkInternalChildren = Symbol('GTK widget template internal children');
 var _gtkTemplate = Symbol('GTK widget template');
 
-function registerClass(klass) {
-    if (arguments.length == 2) {
+function registerClass(...args) {
+    let klass = args[0];
+    if (args.length === 2) {
         // The two-argument form is the convenient syntax without ESnext
         // decorators and class data properties. The first argument is an
         // object with meta info such as properties and signals. The second
@@ -55,8 +56,8 @@ function registerClass(klass) {
         //
         // When decorators and class data properties become part of the JS
         // standard, this function can be used directly as a decorator.
-        let metaInfo = arguments[0];
-        klass = arguments[1];
+        let metaInfo = args[0];
+        klass = args[1];
         if ('GTypeName' in metaInfo)
             klass[GTypeName] = metaInfo.GTypeName;
         if ('GTypeFlags' in metaInfo)
@@ -80,9 +81,10 @@ function registerClass(klass) {
     }
 
     if (!(klass.prototype instanceof GObject.Object) &&
-        !(klass.prototype instanceof GObject.Interface))
+        !(klass.prototype instanceof GObject.Interface)) {
         throw new TypeError('GObject.registerClass() used with invalid base ' +
             `class (is ${Object.getPrototypeOf(klass).name})`);
+    }
 
     // Find the "least derived" class with a _classInit static function; there
     // definitely is one, since this class must inherit from GObject
@@ -94,18 +96,18 @@ function registerClass(klass) {
 
 // Some common functions between GObject.Class and GObject.Interface
 
-function _createSignals(gtype, signals) {
-    for (let signalName in signals) {
-        let obj = signals[signalName];
-        let flags = (obj.flags !== undefined) ? obj.flags : GObject.SignalFlags.RUN_FIRST;
-        let accumulator = (obj.accumulator !== undefined) ? obj.accumulator : GObject.AccumulatorType.NONE;
-        let rtype = (obj.return_type !== undefined) ? obj.return_type : GObject.TYPE_NONE;
-        let paramtypes = (obj.param_types !== undefined) ? obj.param_types : [];
+function _createSignals(gtype, sigs) {
+    for (let signalName in sigs) {
+        let obj = sigs[signalName];
+        let flags = obj.flags !== undefined ? obj.flags : GObject.SignalFlags.RUN_FIRST;
+        let accumulator = obj.accumulator !== undefined ? obj.accumulator : GObject.AccumulatorType.NONE;
+        let rtype = obj.return_type !== undefined ? obj.return_type : GObject.TYPE_NONE;
+        let paramtypes = obj.param_types !== undefined ? obj.param_types : [];
 
         try {
             obj.signal_id = Gi.signal_new(gtype, signalName, flags, accumulator, rtype, paramtypes);
         } catch (e) {
-            throw new TypeError('Invalid signal ' + signalName + ': ' + e.message);
+            throw new TypeError(`Invalid signal ${signalName}: ${e.message}`);
         }
     }
 }
@@ -119,9 +121,8 @@ function _createGTypeName(klass) {
 function _propertiesAsArray(klass) {
     let propertiesArray = [];
     if (klass.hasOwnProperty(properties)) {
-        for (let prop in klass[properties]) {
+        for (let prop in klass[properties])
             propertiesArray.push(klass[properties][prop]);
-        }
     }
     return propertiesArray;
 }
@@ -159,9 +160,9 @@ function _checkInterface(iface, proto) {
         // so that required interfaces don't copy over properties from other
         // interfaces that require them.
         let ifaces = proto.constructor[interfaces];
-        return ((!_interfacePresent(required, proto.constructor) ||
+        return (!_interfacePresent(required, proto.constructor) ||
             ifaces.indexOf(required) > ifaces.indexOf(iface)) &&
-            !(proto instanceof required));
+            !(proto instanceof required);
     }).map(required =>
         // required.name will be present on JS classes, but on introspected
         // GObjects it will be the C name. The alternative is just so that
@@ -179,12 +180,14 @@ function _init() {
 
     function _makeDummyClass(obj, name, upperName, gtypeName, actual) {
         let gtype = GObject.type_from_name(gtypeName);
-        obj['TYPE_' + upperName] = gtype;
-        obj[name] = function(v) { return new actual(v); };
+        obj[`TYPE_${upperName}`] = gtype;
+        obj[name] = function (v) {
+            return new actual(v);
+        };
         obj[name].$gtype = gtype;
     }
 
-    _makeDummyClass(GObject, 'VoidType', 'NONE', 'void', function() {});
+    _makeDummyClass(GObject, 'VoidType', 'NONE', 'void', function () {});
     _makeDummyClass(GObject, 'Char', 'CHAR', 'gchar', Number);
     _makeDummyClass(GObject, 'UChar', 'UCHAR', 'guchar', Number);
     _makeDummyClass(GObject, 'Unichar', 'UNICHAR', 'gint', String);
@@ -221,104 +224,140 @@ function _init() {
 
     _makeDummyClass(GObject, 'Type', 'GTYPE', 'GType', GObject.type_from_name);
 
-    GObject.ParamSpec.char = function(name, nick, blurb, flags, minimum, maximum, default_value) {
-        return GObject.param_spec_char(name, nick, blurb, minimum, maximum, default_value, flags);
+    GObject.ParamSpec.char = function (name, nick, blurb, flags, minimum, maximum, defaultValue) {
+        return GObject.param_spec_char(name, nick, blurb, minimum, maximum, defaultValue, flags);
     };
 
-    GObject.ParamSpec.uchar = function(name, nick, blurb, flags, minimum, maximum, default_value) {
-        return GObject.param_spec_uchar(name, nick, blurb, minimum, maximum, default_value, flags);
+    GObject.ParamSpec.uchar = function (name, nick, blurb, flags, minimum, maximum, defaultValue) {
+        return GObject.param_spec_uchar(name, nick, blurb, minimum, maximum, defaultValue, flags);
     };
 
-    GObject.ParamSpec.int = function(name, nick, blurb, flags, minimum, maximum, default_value) {
-        return GObject.param_spec_int(name, nick, blurb, minimum, maximum, default_value, flags);
+    GObject.ParamSpec.int = function (name, nick, blurb, flags, minimum, maximum, defaultValue) {
+        return GObject.param_spec_int(name, nick, blurb, minimum, maximum, defaultValue, flags);
     };
 
-    GObject.ParamSpec.uint = function(name, nick, blurb, flags, minimum, maximum, default_value) {
-        return GObject.param_spec_uint(name, nick, blurb, minimum, maximum, default_value, flags);
+    GObject.ParamSpec.uint = function (name, nick, blurb, flags, minimum, maximum, defaultValue) {
+        return GObject.param_spec_uint(name, nick, blurb, minimum, maximum, defaultValue, flags);
     };
 
-    GObject.ParamSpec.long = function(name, nick, blurb, flags, minimum, maximum, default_value) {
-        return GObject.param_spec_long(name, nick, blurb, minimum, maximum, default_value, flags);
+    GObject.ParamSpec.long = function (name, nick, blurb, flags, minimum, maximum, defaultValue) {
+        return GObject.param_spec_long(name, nick, blurb, minimum, maximum, defaultValue, flags);
     };
 
-    GObject.ParamSpec.ulong = function(name, nick, blurb, flags, minimum, maximum, default_value) {
-        return GObject.param_spec_ulong(name, nick, blurb, minimum, maximum, default_value, flags);
+    GObject.ParamSpec.ulong = function (name, nick, blurb, flags, minimum, maximum, defaultValue) {
+        return GObject.param_spec_ulong(name, nick, blurb, minimum, maximum, defaultValue, flags);
     };
 
-    GObject.ParamSpec.int64 = function(name, nick, blurb, flags, minimum, maximum, default_value) {
-        return GObject.param_spec_int64(name, nick, blurb, minimum, maximum, default_value, flags);
+    GObject.ParamSpec.int64 = function (name, nick, blurb, flags, minimum, maximum, defaultValue) {
+        return GObject.param_spec_int64(name, nick, blurb, minimum, maximum, defaultValue, flags);
     };
 
-    GObject.ParamSpec.uint64 = function(name, nick, blurb, flags, minimum, maximum, default_value) {
-        return GObject.param_spec_uint64(name, nick, blurb, minimum, maximum, default_value, flags);
+    GObject.ParamSpec.uint64 = function (name, nick, blurb, flags, minimum, maximum, defaultValue) {
+        return GObject.param_spec_uint64(name, nick, blurb, minimum, maximum, defaultValue, flags);
     };
 
-    GObject.ParamSpec.float = function(name, nick, blurb, flags, minimum, maximum, default_value) {
-        return GObject.param_spec_float(name, nick, blurb, minimum, maximum, default_value, flags);
+    GObject.ParamSpec.float = function (name, nick, blurb, flags, minimum, maximum, defaultValue) {
+        return GObject.param_spec_float(name, nick, blurb, minimum, maximum, defaultValue, flags);
     };
 
-    GObject.ParamSpec.boolean = function(name, nick, blurb, flags, default_value) {
-        return GObject.param_spec_boolean(name, nick, blurb, default_value, flags);
+    GObject.ParamSpec.boolean = function (name, nick, blurb, flags, defaultValue) {
+        return GObject.param_spec_boolean(name, nick, blurb, defaultValue, flags);
     };
 
-    GObject.ParamSpec.flags = function(name, nick, blurb, flags, flags_type, default_value) {
-        return GObject.param_spec_flags(name, nick, blurb, flags_type, default_value, flags);
+    GObject.ParamSpec.flags = function (name, nick, blurb, flags, flagsType, defaultValue) {
+        return GObject.param_spec_flags(name, nick, blurb, flagsType, defaultValue, flags);
     };
 
-    GObject.ParamSpec.enum = function(name, nick, blurb, flags, enum_type, default_value) {
-        return GObject.param_spec_enum(name, nick, blurb, enum_type, default_value, flags);
+    GObject.ParamSpec.enum = function (name, nick, blurb, flags, enumType, defaultValue) {
+        return GObject.param_spec_enum(name, nick, blurb, enumType, defaultValue, flags);
     };
 
-    GObject.ParamSpec.double = function(name, nick, blurb, flags, minimum, maximum, default_value) {
-        return GObject.param_spec_double(name, nick, blurb, minimum, maximum, default_value, flags);
+    GObject.ParamSpec.double = function (name, nick, blurb, flags, minimum, maximum, defaultValue) {
+        return GObject.param_spec_double(name, nick, blurb, minimum, maximum, defaultValue, flags);
     };
 
-    GObject.ParamSpec.string = function(name, nick, blurb, flags, default_value) {
-        return GObject.param_spec_string(name, nick, blurb, default_value, flags);
+    GObject.ParamSpec.string = function (name, nick, blurb, flags, defaultValue) {
+        return GObject.param_spec_string(name, nick, blurb, defaultValue, flags);
     };
 
-    GObject.ParamSpec.boxed = function(name, nick, blurb, flags, boxed_type) {
-        return GObject.param_spec_boxed(name, nick, blurb, boxed_type, flags);
+    GObject.ParamSpec.boxed = function (name, nick, blurb, flags, boxedType) {
+        return GObject.param_spec_boxed(name, nick, blurb, boxedType, flags);
     };
 
-    GObject.ParamSpec.object = function(name, nick, blurb, flags, object_type) {
-        return GObject.param_spec_object(name, nick, blurb, object_type, flags);
+    GObject.ParamSpec.object = function (name, nick, blurb, flags, objectType) {
+        return GObject.param_spec_object(name, nick, blurb, objectType, flags);
     };
 
-    GObject.ParamSpec.param = function(name, nick, blurb, flags, param_type) {
-        return GObject.param_spec_param(name, nick, blurb, param_type, flags);
+    GObject.ParamSpec.param = function (name, nick, blurb, flags, paramType) {
+        return GObject.param_spec_param(name, nick, blurb, paramType, flags);
     };
 
     GObject.ParamSpec.override = Gi.override_property;
 
     Object.defineProperties(GObject.ParamSpec.prototype, {
-        'name': { configurable: false,
-                  enumerable: false,
-                  get: function() { return this.get_name() } },
-        '_nick': { configurable: false,
-                   enumerable: false,
-                   get: function() { return this.get_nick() } },
-        'nick': { configurable: false,
-                  enumerable: false,
-                  get: function() { return this.get_nick() } },
-        '_blurb': { configurable: false,
-                    enumerable: false,
-                    get: function() { return this.get_blurb() } },
-        'blurb': { configurable: false,
-                   enumerable: false,
-                   get: function() { return this.get_blurb() } },
-        'default_value': { configurable: false,
-                           enumerable: false,
-                           get: function() { return this.get_default_value() } },
-        'flags':  { configurable: false,
-                    enumerable: false,
-                    get: function() { return GjsPrivate.param_spec_get_flags(this) } },
-        'value_type':  { configurable: false,
-                         enumerable: false,
-                         get: function() { return GjsPrivate.param_spec_get_value_type(this) } },
-        'owner_type':  { configurable: false,
-                         enumerable: false,
-                         get: function() { return GjsPrivate.param_spec_get_owner_type(this) } },
+        'name': {
+            configurable: false,
+            enumerable: false,
+            get() {
+                return this.get_name();
+            },
+        },
+        '_nick': {
+            configurable: false,
+            enumerable: false,
+            get() {
+                return this.get_nick();
+            },
+        },
+        'nick': {
+            configurable: false,
+            enumerable: false,
+            get() {
+                return this.get_nick();
+            },
+        },
+        '_blurb': {
+            configurable: false,
+            enumerable: false,
+            get() {
+                return this.get_blurb();
+            },
+        },
+        'blurb': {
+            configurable: false,
+            enumerable: false,
+            get() {
+                return this.get_blurb();
+            },
+        },
+        'default_value': {
+            configurable: false,
+            enumerable: false,
+            get() {
+                return this.get_default_value();
+            },
+        },
+        'flags': {
+            configurable: false,
+            enumerable: false,
+            get() {
+                return GjsPrivate.param_spec_get_flags(this);
+            },
+        },
+        'value_type': {
+            configurable: false,
+            enumerable: false,
+            get() {
+                return GjsPrivate.param_spec_get_value_type(this);
+            },
+        },
+        'owner_type': {
+            configurable: false,
+            enumerable: false,
+            get() {
+                return GjsPrivate.param_spec_get_owner_type(this);
+            },
+        },
     });
 
     let {GObjectMeta, GObjectInterface} = Legacy.defineGObjectLegacyObjects(GObject);
@@ -328,23 +367,20 @@ function _init() {
 
     // For compatibility with Lang.Class... we need a _construct
     // or the Lang.Class constructor will fail.
-    GObject.Object.prototype._construct = function() {
-        this._init.apply(this, arguments);
+    GObject.Object.prototype._construct = function (...args) {
+        this._init(...args);
         return this;
     };
 
     GObject.registerClass = registerClass;
 
-    GObject.Object._classInit = function(klass) {
+    GObject.Object._classInit = function (klass) {
         let gtypename = _createGTypeName(klass);
-        let gflags = klass.hasOwnProperty(GTypeFlags) ?
-            klass[GTypeFlags] : 0;
-        let gobjectInterfaces = klass.hasOwnProperty(interfaces) ?
-            klass[interfaces] : [];
+        let gflags = klass.hasOwnProperty(GTypeFlags) ? klass[GTypeFlags] : 0;
+        let gobjectInterfaces = klass.hasOwnProperty(interfaces) ? klass[interfaces] : [];
         let propertiesArray = _propertiesAsArray(klass);
         let parent = Object.getPrototypeOf(klass);
-        let gobjectSignals = klass.hasOwnProperty(signals) ?
-            klass[signals] : [];
+        let gobjectSignals = klass.hasOwnProperty(signals) ? klass[signals] : [];
 
         let newClass = Gi.register_type(parent.prototype, gtypename, gflags,
             gobjectInterfaces, propertiesArray);
@@ -373,8 +409,7 @@ function _init() {
                 let id = GObject.signal_lookup(name.slice(3).replace('_', '-'),
                     newClass.$gtype);
                 if (id !== 0) {
-                    GObject.signal_override_class_closure(id, newClass.$gtype, function() {
-                        let argArray = Array.from(arguments);
+                    GObject.signal_override_class_closure(id, newClass.$gtype, function (...argArray) {
                         let emitter = argArray.shift();
 
                         return func.apply(emitter, argArray);
@@ -387,7 +422,7 @@ function _init() {
             _checkInterface(iface, newClass.prototype));
 
         // For backwards compatibility only. Use instanceof instead.
-        newClass.implements = function(iface) {
+        newClass.implements = function (iface) {
             if (iface.$gtype)
                 return GObject.type_is_a(newClass.$gtype, iface.$gtype);
             return false;
@@ -396,16 +431,14 @@ function _init() {
         return newClass;
     };
 
-    GObject.Interface._classInit = function(klass) {
+    GObject.Interface._classInit = function (klass) {
         let gtypename = _createGTypeName(klass);
-        let gobjectInterfaces = klass.hasOwnProperty(requires) ?
-            klass[requires] : [];
-        let properties = _propertiesAsArray(klass);
-        let gobjectSignals = klass.hasOwnProperty(signals) ?
-            klass[signals] : [];
+        let gobjectInterfaces = klass.hasOwnProperty(requires) ? klass[requires] : [];
+        let props = _propertiesAsArray(klass);
+        let gobjectSignals = klass.hasOwnProperty(signals) ? klass[signals] : [];
 
         let newInterface = Gi.register_interface(gtypename, gobjectInterfaces,
-            properties);
+            props);
 
         _createSignals(newInterface.$gtype, gobjectSignals);
 
@@ -422,9 +455,8 @@ function _init() {
             // SomeInterface.prototype.some_function.call(this, blah)
             if (typeof descr.value === 'function') {
                 let interfaceProto = klass.prototype;  // capture in closure
-                newInterface[key] = function () {
-                    return interfaceProto[key].call.apply(interfaceProto[key],
-                        arguments);
+                newInterface[key] = function (thisObj, ...args) {
+                    return interfaceProto[key].call(thisObj, ...args);
                 };
             }
 
@@ -439,7 +471,9 @@ function _init() {
      * implementation of the interface.
      */
     GObject.NotImplementedError = class NotImplementedError extends Error {
-        get name() { return 'NotImplementedError'; }
+        get name() {
+            return 'NotImplementedError';
+        }
     };
 
     // These will be copied in the Gtk overrides
@@ -459,7 +493,7 @@ function _init() {
     GObject.signals = signals;
 
     // Replacement for non-introspectable g_object_set()
-    GObject.Object.prototype.set = function(params) {
+    GObject.Object.prototype.set = function (params) {
         Object.assign(this, params);
     };
 
@@ -467,10 +501,10 @@ function _init() {
     GObject.AccumulatorType = {
         NONE: 0,
         FIRST_WINS: 1,
-        TRUE_HANDLED: 2
+        TRUE_HANDLED: 2,
     };
 
-    GObject.Object.prototype.disconnect = function(id) {
+    GObject.Object.prototype.disconnect = function (id) {
         return GObject.signal_handler_disconnect(this, id);
     };
 
@@ -478,13 +512,13 @@ function _init() {
     // methods (such as Gio.Socket.connect or NMClient.Device.disconnect)
     // The original g_signal_* functions are not introspectable anyway, because
     // we need our own handling of signal argument marshalling
-    GObject.signal_connect = function(object, name, handler) {
+    GObject.signal_connect = function (object, name, handler) {
         return GObject.Object.prototype.connect.call(object, name, handler);
     };
-    GObject.signal_connect_after = function(object, name, handler) {
+    GObject.signal_connect_after = function (object, name, handler) {
         return GObject.Object.prototype.connect_after.call(object, name, handler);
     };
-    GObject.signal_emit_by_name = function(object, ...nameAndArgs) {
+    GObject.signal_emit_by_name = function (object, ...nameAndArgs) {
         return GObject.Object.prototype.emit.apply(object, nameAndArgs);
     };
 }
